# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_stopcustomaction.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_stopcustomaction.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1e\x63odemao_stopcustomaction.proto\"-\n\x17StopCustomActionRequest\x12\x12\n\nactionName\x18\x01 \x01(\t\"A\n\x18StopCustomActionResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_STOPCUSTOMACTIONREQUEST = _descriptor.Descriptor(
    name='StopCustomActionRequest',
    full_name='StopCustomActionRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='actionName', full_name='StopCustomActionRequest.actionName', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=34,
    serialized_end=79,
)

_STOPCUSTOMACTIONRESPONSE = _descriptor.Descriptor(
    name='StopCustomActionResponse',
    full_name='StopCustomActionResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='StopCustomActionResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='StopCustomActionResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=81,
    serialized_end=146,
)

DESCRIPTOR.message_types_by_name['StopCustomActionRequest'] = _STOPCUSTOMACTIONREQUEST
DESCRIPTOR.message_types_by_name['StopCustomActionResponse'] = _STOPCUSTOMACTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StopCustomActionRequest = _reflection.GeneratedProtocolMessageType('StopCustomActionRequest', (_message.Message,), {
    'DESCRIPTOR': _STOPCUSTOMACTIONREQUEST,
    '__module__': 'codemao_stopcustomaction_pb2'
    # @@protoc_insertion_point(class_scope:StopCustomActionRequest)
})
_sym_db.RegisterMessage(StopCustomActionRequest)

StopCustomActionResponse = _reflection.GeneratedProtocolMessageType('StopCustomActionResponse', (_message.Message,), {
    'DESCRIPTOR': _STOPCUSTOMACTIONRESPONSE,
    '__module__': 'codemao_stopcustomaction_pb2'
    # @@protoc_insertion_point(class_scope:StopCustomActionResponse)
})
_sym_db.RegisterMessage(StopCustomActionResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
